==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTSensor.md <==
# AwsIoTSensor


```text
aws-20210730/Resource/LoT/AwsIoTSensor
```

```text
include('aws-20210730/Resource/LoT/AwsIoTSensor')
```



| Illustration | AwsIoTSensor | AwsIoTSensorCard | AwsIoTSensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTSensor.png) | ![illustration for AwsIoTSensor](../../../aws-20210730/Resource/LoT/AwsIoTSensor.Local.png) | ![illustration for AwsIoTSensorCard](../../../aws-20210730/Resource/LoT/AwsIoTSensorCard.Local.png) | ![illustration for AwsIoTSensorGroup](../../../aws-20210730/Resource/LoT/AwsIoTSensorGroup.Local.png) |




## AwsIoTSensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensor
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensor('AwsIoTSensor', 'Aws Io T Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensor
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensor('AwsIoTSensor', 'Aws Io T Sensor', 'an optional tech label')
@enduml
```

## AwsIoTSensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorCard
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorCard('AwsIoTSensorCard', 'Aws Io T Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorCard
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorCard('AwsIoTSensorCard', 'Aws Io T Sensor Card', 'an optional description')
@enduml
```

## AwsIoTSensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorGroup('AwsIoTSensorGroup', 'Aws Io T Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorGroup('AwsIoTSensorGroup', 'Aws Io T Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTSensor.md <==
# AwsIoTSensor


```text
aws-20210730/Resource/LoT/AwsIoTSensor
```

```text
include('aws-20210730/Resource/LoT/AwsIoTSensor')
```



| Illustration | AwsIoTSensor | AwsIoTSensorCard | AwsIoTSensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTSensor.png) | ![illustration for AwsIoTSensor](../../../aws-20210730/Resource/LoT/AwsIoTSensor.Local.png) | ![illustration for AwsIoTSensorCard](../../../aws-20210730/Resource/LoT/AwsIoTSensorCard.Local.png) | ![illustration for AwsIoTSensorGroup](../../../aws-20210730/Resource/LoT/AwsIoTSensorGroup.Local.png) |




## AwsIoTSensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensor
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensor('AwsIoTSensor', 'Aws Io T Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensor
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensor('AwsIoTSensor', 'Aws Io T Sensor', 'an optional tech label')
@enduml
```

## AwsIoTSensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorCard
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorCard('AwsIoTSensorCard', 'Aws Io T Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorCard
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorCard('AwsIoTSensorCard', 'Aws Io T Sensor Card', 'an optional description')
@enduml
```

## AwsIoTSensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorGroup('AwsIoTSensorGroup', 'Aws Io T Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTSensor')

' renders the element
AwsIoTSensorGroup('AwsIoTSensorGroup', 'Aws Io T Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
